Index: /CKEditor/branches/features/adobeair/_source/plugins/scayt/plugin.js
===================================================================
--- /CKEditor/branches/features/adobeair/_source/plugins/scayt/plugin.js	(revision 5633)
+++ /CKEditor/branches/features/adobeair/_source/plugins/scayt/plugin.js	(revision 5634)
@@ -358,7 +358,11 @@
 		loadEngine : function( editor )
 		{
-			// SCAYT doesn't work with Firefox2, Opera.
-			if ( CKEDITOR.env.gecko && CKEDITOR.env.version < 10900 || CKEDITOR.env.opera )
+			// SCAYT doesn't work with Adobe AIR, Firefox2, Opera.
+			if ( CKEDITOR.env.air
+				|| CKEDITOR.env.gecko && CKEDITOR.env.version < 10900
+				|| CKEDITOR.env.opera )
+			{
 				return editor.fire( 'showScaytState' );
+			}
 
 			if ( this.engineLoaded === true )
